<?php
/**
 * @file
 * Administration settings for Lyris API integration.
 */
/**
 * Lyris Settings Form.
 * FORM
 */
function lyris_connection_settings_form($form, &$form_state) {
  $wsdl_sb    = variable_get('lyris_wsdl_sandbox');
  $wsdl_prod  = variable_get('lyris_wsdl_production');
  $lyris_sb   = ($wsdl_sb ? lyris('admin', 'sandbox') : NULL);
  $lyris_prod = ($wsdl_prod ? lyris('admin', 'production') : NULL);
  $user       = lyris_global_user();

  $admin = variable_get('lyris_connection');

  // Connection mode
  $form['lyris_mode'] = array(
    '#type' => 'radios',
    '#title' => t('Connection Mode'),
    '#description' => t('<strong>Offline:</strong> Create and edit Lyris lists, content and members locally without a connection to Lyris.  Data will be synced when Lyris is accessible.') . '<br />' .
                      t('<strong>Sandbox:</strong> Only lists, content and members belonging to the Sandbox server are shown and therefore editable.') . '<br />' .
                      t('<strong>Production:</strong> Only lists, content and members belonging to the Production server are shown and therefore editable.'),
    '#options' => _lyris_options('lyris_mode'),
    '#default_value' => variable_get('lyris_mode', LYRIS_MODE_DEFAULT),
    '#required' => TRUE,
  );

  $form['lyris_mode_display'] = array(
    '#type' => 'checkbox',
    '#title' => t('Mode Display'),
    '#description' => t('Display the mode Lyris connection mode on administrative pages.'),
    '#default_value' => variable_get('lyris_mode_display', LYRIS_MODE_DISPLAY_DEFAULT),
  );

  // Sandbox server
  $form['lyris_sandbox'] = array(
    '#type' => 'fieldset',
    '#title' => t('Sandbox Server'),
    '#description' => t('Information about the Lyris Sandbox server.'),
    '#collapsible' => TRUE,
    '#collapsed' => empty($wsdl_sb),
  );
  $form['lyris_sandbox']['lyris_wsdl_sandbox'] = array(
    '#type' => 'textfield',
    '#title' => t('WSDL Location'),
    '#description' => t('Provide the location to your WSDL files.'),
    '#default_value' => $wsdl_sb,
  );
  $form['lyris_sandbox']['lyris_admin_sandbox'] = array(
    '#type' => 'item',
    '#title' => t('Admin Credentials'),
    '#markup' => (isset($admin['sandbox']) && !empty($admin['sandbox']) ? t('Admin credentials are set.') : t('Admin credentials need to be defined in your settings.php file.')),
  );
  $form['lyris_sandbox']['lyris_api_display_sandbox'] = array(
    '#type' => 'item',
    '#title' => t('Lyris API Version'),
    '#markup' => ($wsdl_sb && $lyris_sb->isConnected() ? $lyris_sb->api_version : t('Not connected to Lyris.')),
  );

  // Production Server
  $form['lyris_production'] = array(
    '#type' => 'fieldset',
    '#title' => t('Production Server'),
    '#description' => t('Information about the Lyris Production server.'),
    '#collapsible' => TRUE,
    '#collapsed' => empty($wsdl_prod),
  );
  $form['lyris_production']['lyris_wsdl_production'] = array(
    '#type' => 'textfield',
    '#title' => t('WSDL Location'),
    '#description' => t('Provide the location to your WSDL files.'),
    '#default_value' => $wsdl_prod,
  );
  $form['lyris_production']['lyris_admin_production'] = array(
    '#type' => 'item',
    '#title' => t('Admin Credentials'),
    '#markup' => (isset($admin['production']) && !empty($admin['production']) ? t('Admin credentials are set.') : t('Admin credentials need to be defined in your settings.php file.')),
  );
  $form['lyris_production']['lyris_api_display_production'] = array(
    '#type' => 'item',
    '#title' => t('Lyris API Version'),
    '#markup' => ($wsdl_prod && $lyris_prod->isConnected() ? $lyris_prod->api_version : t('Not connected to Lyris.')),
  );

  $form['lyris_log_connection'] = array(
    '#type' => 'checkbox',
    '#title' => t('Log Connection Requests'),
    '#description' => t('Log all API connection requests to watchdog.'),
    '#default_value' => variable_get('lyris_log_connection'),
  );

  return system_settings_form($form);
}

/**
 * Lyris settings form.
 * VALIDATE
 */
function lyris_connection_settings_form_validate($form, &$form_state) {
  $vals = $form_state['values'];

  // Ensure we have credentials provided for the mode the user selected.
  if (empty($vals['lyris_wsdl_' . $vals['lyris_mode']]) && $vals['lyris_mode'] != LYRIS_MODE_OFFLINE) {
    form_set_error('lyris_wsdl_' . $vals['lyris_mode'], t('A @mode WSDL location must be provided to enable @mode mode.', array('@mode' => $vals['lyris_mode'])));
  }
}

/**
 * Lyris settings form.
 * SUBMIT
 */
function lyris_connection_settings_form_submit($form, &$form_state) {
  // Rebuild the menu to enable certain features depending on settings.
  menu_rebuild();
}

/**
 * Basic List settings form.
 */
function lyris_basic_settings_form($form, &$form_state) {
  $form['lyris_list_prefix'] = array(
    '#type' => 'textfield',
    '#title' => t('List Name Prefix'),
    '#description' => t('Add a prefix to each listname to make them easier to locate in Lyris and to prevent collisions with other similarly named lists. (Only applies to new lists.)') . '<br /><em>' . t('Value may contain only lowercase alphanumerics, underscores and hyphens.') . '</em>',
    '#maxlength' => 16,
    '#size' => 20,
    '#default_value' => variable_get('lyris_list_prefix'),
    '#element_validate' => array('lyris_validate_machine_name'),
  );

  $form['lyris_member_name_pattern'] = array(
    '#type' => 'textfield',
    '#title' => t('Member Name Pattern'),
    '#description' => t('When a Drupal user is saved as a Lyris member, use tokens to generate their full name.  This may be used in mailing substitutions later.  If no name is provided it will default to their e-mail address.'),
    '#default_value' => variable_get('lyris_member_name_pattern', '[user:name]'),
  );
  $form['lyris_token_ref'] = array(
    '#theme' => 'token_tree',
    '#token_types' => array('user'),
    '#global_types' => FALSE,
  );

  return system_settings_form($form);
}

/**
 * Manage cron settings for Lyris syncing.
 * FORM
 */
function lyris_cron_settings_form($form, &$form_state) {
  $form['lyris_sync_threshold'] = array(
    '#type' => 'textfield',
    '#title' => t('Bulk Sync Threshold'),
    '#description' => t('Set a maximum number of records to directly push to Lyris before cron batching is invoked.') . '<br />' .
                      t('Ex. If set to 3, then subscribing up to 3 members at a time will push directly to Lyris on submission.  Four members or more will be updated locally and queued for sync on the next cron run.'),
    '#size' => 10,
    '#maxlength' => 5,
    '#element_validate' => '_lyris_element_validate_integer',
    '#default_value' => variable_get('lyris_sync_threshold', LYRIS_SYNC_THRESHOLD_DEFAULT),
  );
  $form['lyris_sync_cron_interval'] = array(
    '#type' => 'textfield',
    '#title' => t('Sync Interval'),
    '#description' => t('How often do you want to check for unsynced records?') . '<br /><em>' . t('Remember to configure your server\'s cron task to run at least as frequently as this setting.') . '</em>',
    '#size' => 10,
    '#maxlength' => 5,
    '#field_prefix' => t('Every'),
    '#field_suffix' => t('minutes'),
    '#element_validate' => '_lyris_element_validate_integer',
    '#default_value' => variable_get('lyris_sync_cron_interval', 60),
  );
  $form['lyris_sync_cron_batch_count'] = array(
    '#type' => 'textfield',
    '#title' => t('Sync Limit'),
    '#size' => 10,
    '#maxlength' => 5,
    '#description' => t('What is the maximum number of records to sync per attempt?  Set to 0 for unlimited.'),
    '#element_validate' => '_lyris_element_validate_integer',
    '#default_value' => variable_get('lyris_sync_cron_batch_count', 100),
  );

  return system_settings_form($form);
}
