<?php
/**
 * @file
 * General page displays for Lyris configuration and management.
 */
/**
 * Lyris List overview table.
 */
function lyris_page_lists() {
  $lists = lyris_get_lists();
  $field_ui = module_exists('field_ui');
  $members  = module_exists('lyris_member');
  $header = array(
    t('List Name'),
    //t('Created/Imported'),
    //t('Updated'),
    array('data' => t('Operations'),         'colspan' => ($field_ui ? '5' : '3')),
    array('data' => t('Content & Mailings'), 'colspan' => ($members  ? '3' : '2')),
  );
  $rows = array();
  
  foreach ($lists as $list) {
    // Check remote user permissions
    if (!lyris_access_remote($list[llf('ListName')])) {
      continue;
    }
    
    $url = lyris_url_str($list[llf('ListName')]);
    $creator = user_load($list['creator']);
    $changer = user_load($list['changer']);

    $row = array(theme('lyris_list_admin_overview', array('list' => $list)));

    // Created/Imported
    //$row[] = array('data' => theme('lyris_list_admin_created', array('origin' => $list['origin'], 'created' => $list['created'], 'creator' => $creator)));

    // Updated
    //$row[] = array('data' => theme('lyris_list_admin_changed', array('changed' => $list['changed'], 'changer' => $changer)));

    // OPERATIONS
    $row[] = array('data' => l(t('view'), 'admin/structure/lyris/lists/' . $list['eid']));
    $row[] = array('data' => l(t('edit'), 'admin/structure/lyris/lists/' . $list['eid'] . '/edit'));
    if ($field_ui) {
      $row[] = array('data' => l(t('manage fields'), 'admin/structure/lyris/lists/' . $list['eid'] . '/fields'));
      $row[] = array('data' => l(t('manage display'), 'admin/structure/lyris/lists/' . $list['eid'] . '/display'));
    }
    $row[] = array('data' => l(t('delete'), 'admin/structure/lyris/lists/' . $list['eid'] . '/delete'));

    // MAILINGS
    $row[] = array('data' => l(t('set defaults'), 'admin/structure/lyris/lists/' . $list['eid'] . '/defaults'));
    $row[] = array('data' => l(t('view content'), 'admin/content/lyris/' . $list['eid']));
    if ($members) {
      $row[] = array('data' => l(t('list members'), 'admin/structure/lyris/lists/' . $list['eid'] . '/members'));
    }

    $rows[] = $row;
  }

  $build['lyris_list_table'] = array(
    '#theme' => 'table',
    '#header' => $header,
    '#rows' => $rows,
    '#empty' => t('No mailing lists available.'),
  );
  if (variable_get('lyris_mode_display', LYRIS_MODE_DISPLAY_DEFAULT)) {
    $build['lyris_list_table']['#caption'] = theme('lyris_mode_indicator');
  }

  return $build;
}

/**
 * List overview page.
 */
function lyris_list_view(LyrisList $list) {
  lyris_include('forms');
  drupal_set_title(t('!name Settings', array('!name' => $list->getDisplayName())));

  $lyris = lyris(NULL, $list->server);
  $out = '';

  $remote = $lyris->loadList(array('ListName' => $list->localVal('ListName')));

  // Show field comparison
  $out .= '<h2>' . t('Sync Status') . '</h2>';
  $form = drupal_get_form('lyris_entity_field_comparison_form', $list, $remote);
  $out .= drupal_render($form);

  // Get Sync Status
  $out .= '<h2>' . t('Update Status') . '</h2>';
  $out .= theme('lyris_entity_sync_status', array('entity' => $list));

  if ($list->hasChanges()) {
    $form = drupal_get_form('lyris_entity_quick_push_form', $list);
    $out .= drupal_render($form);
  }

  // Show/import content

  // Show/import members

  return $out;
}

/**
 * Page listing available mailing lists to create new mailing list content.
 */
function lyris_content_add_page() {
  $item = menu_get_item();
  $content = system_admin_menu_block($item);
   
  // Bypass the lyris/add listing if only one list is available.
  if (count($content) == 1) {
    $item = array_shift($content);
    drupal_goto($item['href']);
  }

  return theme('lyris_add_page', array('content' => $content));
}

/**
 * Listing of Lyris content.
 *
 * @param LyrisList $list
 *   An optional lyris list entity to filter the content.
 *
 * @todo Build out better content listing table.
 */
function lyris_content_listing($list = NULL) {
  $sel = db_select(LYRIS_CONTENT_TABLE, 'lc')->fields('lc');

  // Filter by the list if one was set.
  if (is_object($list)) {
    drupal_set_title(t('Mailing List Content for !title', array('!title' => $list->title)));
    $sel->condition('lc.' . llf('ListName'), $list->localVal('ListName'));
  }

  $res = $sel->execute();

  $rows = array();
  while ($content = $res->fetchAssoc()) {
    $row = array(
      $content[llf('Title')],
      $content[llf('ListName')],
      l('edit', 'lyris/content/' . $content['eid'] . '/edit'),
      l('mailings', 'lyris/content/' . $content['eid'] . '/mailings'),
    );
    $rows[] = $row;
  }

  $headers = array(
    t('Content Title'),
    t('ListName'),
    array('data' => t('Operations'), 'colspan' => 2),
  );

  $output['content'] = array(
    '#theme' => 'table',
    '#header' => $headers,
    '#rows' => $rows,
    '#empty' => t('No content available.'),
  );

  return $output;
}

/**
 * Returns a list content submission form.
 */
function lyris_content_add($list_eid) {
  $user = lyris_global_user();
  $list = lyris_list_load($list_eid);
  
  // Prepare initial $lyris_content item.
  $lc = lyris_content($list->eid);

  drupal_set_title(t('Create Content for @name', array('@name' => $list->getDisplayName())), PASS_THROUGH);
  $output = drupal_get_form($list->localVal('ListName') . '_lyris_content_form', $lc);

  return $output;
}

/**
 * Returns a list-content edit form.
 */
function lyris_content_edit($lc) {
  drupal_set_title(t("Edit '@name'", array('@name' => $lc->getDisplayName())), PASS_THROUGH);
  $output = drupal_get_form($lc->localVal('ListName') . '_lyris_content_form', $lc);

  return $output;
}

/**
 * Display Lyris Content.
 *
 * @todo Setup display modes.
 */
function lyris_content_page($lc) {
  $out = theme('lyris_helper_tools', array('content' => $lc));
  return $out;
}

/**
 * Display the mailing form with the preview.
 */
function lyris_mailing_page($lc) {
  lyris_include('forms');
  
  $list = lyris_list_load($lc->localVal('ListName'));
  $mailing = lyris_mailing($lc);
  $title = t('Deliver \'@mailing\' to \'@list\'', array('@mailing' => $lc->getDisplayName(), '@list' => $list->getDisplayName()));
  drupal_set_title($title);
  
  $out = theme('lyris_helper_tools', array('list' => $list, 'content' => $lc));
  
  $form = drupal_get_form('lyris_mailing_form', $list, $lc, $mailing);
  
  $mailing->content_eid = $lc->eid;
  $mailing->list_eid = $list->eid;
  
  $out .= '<div id="lyris-mailing">';
  $out .= '<div class="col left">' . drupal_render($form) . '</div>';
  $out .= '<div class="col right">' . theme('lyris_mailing_preview', array('mailing' => $mailing)) . '</div>';
  $out .= '</div>';
  
  return $out;
}

/**
 * Print the plain body content of the mailing.
 */
function lyris_mailing_content_preview($lc) {
  $content = '';
  $is_html = FALSE;
  foreach (field_get_items('lyris_content', $lc, 'lyris_content_docparts') as $instance) {
    $content .= $instance['safe_value'];
    if (lyris_textfield_mimetype($instance) == 'html') {
      $is_html = TRUE;
    }
  }
  
  $data = array('lyris_content' => $lc, 'lyris_list' => lyris_list_load($lc->localVal('ListName')));
    
  print theme('lyris_mailing_preview_content', array('content' => token_replace($content, $data), 'is_html' => $is_html));
}